@@ -8,6 +8,7 @@ class Sugarcoat:
 		"Store": "stores",
 		"Product": "products",
 		"Basket": "baskets",
+		"Categories": "categories",
 		"ProductTypes": "product-types",
 		"User": "users",
 		"Customer": "customers",
@@ -17,7 +18,8 @@ class Sugarcoat:
 		"ProductGroups": "product-groups",
 		"Tag": "tags",
 		"DeliveryTypes" :"delivery-types",
-		"Terms": "terms"
+		"Terms": "terms",
+		"Brands": "brands"
 	}
 
 	endpoints_second_level = {
